==> zio-aws-ec2_2.12-7.21.15.12-sources.jar: zio/aws/ec2/model/CreateCoipCidrRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Ipv4PoolCoipId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateCoipCidrRequest(
    cidr: String,
    coipPoolId: Ipv4PoolCoipId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest = {
    import CreateCoipCidrRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
      .builder()
      .cidr(cidr: java.lang.String)
      .coipPoolId(Ipv4PoolCoipId.unwrap(coipPoolId): java.lang.String)
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CreateCoipCidrRequest.ReadOnly =
    zio.aws.ec2.model.CreateCoipCidrRequest.wrap(buildAwsValue())
}
object CreateCoipCidrRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateCoipCidrRequest = zio.aws.ec2.model
      .CreateCoipCidrRequest(cidr, coipPoolId, dryRun.map(value => value))
    def cidr: String
    def coipPoolId: Ipv4PoolCoipId
    def dryRun: Optional[Boolean]
    def getCidr: ZIO[Any, Nothing, String] = ZIO.succeed(cidr)
    def getCoipPoolId: ZIO[Any, Nothing, Ipv4PoolCoipId] =
      ZIO.succeed(coipPoolId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
  ) extends zio.aws.ec2.model.CreateCoipCidrRequest.ReadOnly {
    override val cidr: String = impl.cidr(): String
    override val coipPoolId: Ipv4PoolCoipId =
      zio.aws.ec2.model.primitives.Ipv4PoolCoipId(impl.coipPoolId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
  ): zio.aws.ec2.model.CreateCoipCidrRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.295.22-sources.jar: zio/aws/ec2/model/CreateCoipCidrRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Ipv4PoolCoipId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class CreateCoipCidrRequest(
    cidr: String,
    coipPoolId: Ipv4PoolCoipId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest = {
    import CreateCoipCidrRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
      .builder()
      .cidr(cidr: java.lang.String)
      .coipPoolId(Ipv4PoolCoipId.unwrap(coipPoolId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.CreateCoipCidrRequest.ReadOnly =
    zio.aws.ec2.model.CreateCoipCidrRequest.wrap(buildAwsValue())
}
object CreateCoipCidrRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateCoipCidrRequest =
      zio.aws.ec2.model.CreateCoipCidrRequest(cidr, coipPoolId)
    def cidr: String
    def coipPoolId: Ipv4PoolCoipId
    def getCidr: ZIO[Any, Nothing, String] = ZIO.succeed(cidr)
    def getCoipPoolId: ZIO[Any, Nothing, Ipv4PoolCoipId] =
      ZIO.succeed(coipPoolId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
  ) extends zio.aws.ec2.model.CreateCoipCidrRequest.ReadOnly {
    override val cidr: String = impl.cidr(): String
    override val coipPoolId: Ipv4PoolCoipId =
      zio.aws.ec2.model.primitives.Ipv4PoolCoipId(impl.coipPoolId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateCoipCidrRequest
  ): zio.aws.ec2.model.CreateCoipCidrRequest.ReadOnly = new Wrapper(impl)
}
